pygeodesy.ltp.Ltp

Package pygeodesy :: Module ltp :: Class Ltp |
[frames] | no frames]

# Class Ltp

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
          LocalCartesian --+
                           |
                          Ltp

Known Subclasses:
  - ChLV

A local tangent plan (LTP), a sub-class of `LocalCartesian` with (re-)configurable ECEF converter.

Instance Methods
__init__(self, latlonh0=0, lon0=0, height0=0, ecef=None, **lon00_name) New `Ltp`, see LocalCartesian.__init__ for more details. |
Inherited from `LocalCartesian`: `__eq__`, `forward`, `reset`, `reverse`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| ecef Get this LTP's ECEF converter (`Ecef...` instance).
Inherited from `LocalCartesian`: `M`, `datum`, `ellipsoid`, `height0`, `lat0`, `latlonheight0`, `lon0`, `lon00` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, latlonh0=0, lon0=0, height0=0, ecef=None, **lon00_name) (Constructor) |
New `Ltp`, see LocalCartesian.__init__ for more details. Arguments: `ecef` - Optional ECEF converter (EcefKarney, EcefFarrell21, EcefFarrell22, EcefSudano, EcefVeness or EcefYou instance), overriding the default EcefKarney`(datum=Datums.WGS84)` for `scalar`. Raises: `TypeError` - Invalid `ecef`. Overrides: object.__init__ See Also: Class LocalCartesian for further details.

Property Details

### ecef Get this LTP's ECEF converter (`Ecef...` instance). Get method: ecef(self) - Get this LTP's ECEF converter (`Ecef...` instance). Set method: ecef(self, ecef) - Set this LTP's ECEF converter (`Ecef...` instance). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.